@@ -18,8 +18,8 @@ hist(resids[,1])
 
 ## -----------------------------------------------------------------------------
 set.seed(100)
-system.time(pc.out <- BiocSingular::runPCA(resids, 10, 
-    BSPARAM=BiocSingular::RandomParam(deferred=TRUE)))
+system.time(pc.out <- BiocSingular::runPCA(resids, 10, center=FALSE,
+    BSPARAM=BiocSingular::RandomParam()))
 str(pc.out)
 
 ## -----------------------------------------------------------------------------
